Security Advisories (7)
CPANSA-Mojolicious-2022-03 (2022-12-10)

Mojo::DOM did not correctly parse <script> tags.

CPANSA-Mojolicious-2021-02 (2021-06-01)

Small sessions could be used as part of a brute-force attack to decode the session secret.

CVE-2021-47208 (2021-03-16)

A bug in format detection can potentially be exploited for a DoS attack.

CPANSA-Mojolicious-2018-04 (2018-08-09)

This release reverts the addition of stream classes (added in 7.83), which have unfortunately resulted in many Mojolicious applications becoming unstable. While there are no known exploits yet, we've chosen to err on the side of cautiousness and will classify this as a security issue.

CVE-2020-36829 (2020-11-10)

Mojo::Util secure_compare can leak the string length. By immediately returning when the two strings are not the same length, the function allows an attacker to guess the length of the secret string using timing attacks.

CVE-2024-58134 (2025-05-03)

Mojolicious versions from 0.999922 for Perl uses a hard coded string, or the application's class name, as a HMAC session secret by default. These predictable default secrets can be exploited to forge session cookies. An attacker who knows or guesses the secret could compute valid HMAC signatures for the session cookie, allowing them to tamper with or hijack another user's session.

CVE-2024-58135 (2025-05-03)

Mojolicious versions from 7.28 for Perl may generate weak HMAC session secrets. When creating a default app with the "mojo generate app" tool, a weak secret is written to the application's configuration file using the insecure rand() function, and used for authenticating and protecting the integrity of the application's sessions. This may allow an attacker to brute force the application's session keys.

NAME

Mojo::UserAgent::Server - Application server

SYNOPSIS

use Mojo::UserAgent::Server;

my $server = Mojo::UserAgent::Server->new;
say $server->url;

DESCRIPTION

Mojo::UserAgent::Server is an embedded web server based on Mojo::Server::Daemon that processes requests for Mojo::UserAgent.

ATTRIBUTES

Mojo::UserAgent::Server implements the following attributes.

ioloop

my $loop = $server->ioloop;
$server  = $server->ioloop(Mojo::IOLoop->new);

Event loop object to use for I/O operations, defaults to the global Mojo::IOLoop singleton.

METHODS

Mojo::UserAgent::Server inherits all methods from Mojo::Base and implements the following new ones.

app

my $app = Mojo::UserAgent::Server->app;
          Mojo::UserAgent::Server->app(Mojolicious->new);
my $app = $server->app;
$server = $server->app(Mojolicious->new);

Application this server handles, instance specific applications override the global default.

# Change application behavior
$server->app->defaults(testing => 'oh yea!');

nb_url

my $url = $ua->nb_url;
my $url = $ua->nb_url('http');
my $url = $ua->nb_url('https');

Get absolute Mojo::URL object for server processing non-blocking requests with "app" and switch protocol if necessary.

restart

$server->restart;

Restart server with new port.

url

my $url = $ua->url;
my $url = $ua->url('http');
my $url = $ua->url('https');

Get absolute Mojo::URL object for server processing blocking requests with "app" and switch protocol if necessary.

SEE ALSO

Mojolicious, Mojolicious::Guides, https://mojolicious.org.